@@ -228,7 +228,7 @@ void VCardTool::processEmailList(const Email::List &emailList, VCard::Version ve
 
 void VCardTool::processOrganizations(const Addressee &addressee, VCard::Version version, VCard *card) const
 {
-    const QVector<Org> lstOrg = addressee.extraOrganizationList();
+    const QList<Org> lstOrg = addressee.extraOrganizationList();
     for (const Org &org : lstOrg) {
         QStringList organization{org.organization().replace(QLatin1Char(';'), QLatin1String("\\;"))};
         if (!addressee.department().isEmpty()) {
@@ -366,19 +366,15 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         const QString birthdayString = createDateTime(addressee.birthday(), version, withTime);
         card.addLine(VCardLine(QStringLiteral("BDAY"), birthdayString));
 
-        // Laurent: 31 Jan 2015. Not necessary to export it. When Categories were changes as AkonadiTag nobody thought that it would break categories support...
-        //=> not necessary to export just tag...
         // CATEGORIES only > 2.1
-        if (!exportVcard) {
-            if (version != VCard::v2_1) {
-                QStringList categories = addressee.categories();
-                for (auto &cat : categories) {
-                    cat.replace(QLatin1Char(','), QLatin1String("\\,"));
-                }
-
-                VCardLine catLine(QStringLiteral("CATEGORIES"), categories.join(QLatin1Char(',')));
-                card.addLine(catLine);
+        if (version != VCard::v2_1) {
+            QStringList categories = addressee.categories();
+            for (auto &cat : categories) {
+                cat.replace(QLatin1Char(','), QLatin1String("\\,"));
             }
+
+            VCardLine catLine(QStringLiteral("CATEGORIES"), categories.join(QLatin1Char(',')));
+            card.addLine(catLine);
         }
         // MEMBER (only in 4.0)
         if (version == VCard::v4_0) {
@@ -391,7 +387,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
             }
         }
         // SOURCE
-        const QVector<QUrl> lstUrl = addressee.sourcesUrlList();
+        const QList<QUrl> lstUrl = addressee.sourcesUrlList();
         for (const QUrl &url : lstUrl) {
             VCardLine line = VCardLine(QStringLiteral("SOURCE"), url.url());
             card.addLine(line);
@@ -457,7 +453,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
 
         // LOGO
         card.addLine(createPicture(QStringLiteral("LOGO"), addressee.logo(), version));
-        const QVector<Picture> lstLogo = addressee.extraLogoList();
+        const QList<Picture> lstLogo = addressee.extraLogoList();
         for (const Picture &logo : lstLogo) {
             card.addLine(createPicture(QStringLiteral("LOGO"), logo, version));
         }
@@ -503,7 +499,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
 
         // NICKNAME only for version > 2.1
         if (version != VCard::v2_1) {
-            const QVector<NickName> lstNickName = addressee.extraNickNameList();
+            const QList<NickName> lstNickName = addressee.extraNickNameList();
             for (const NickName &nickName : lstNickName) {
                 VCardLine nickNameLine(QStringLiteral("NICKNAME"), nickName.nickname());
                 nickNameLine.addParameters(nickName.params());
@@ -525,7 +521,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
 
         // PHOTO
         card.addLine(createPicture(QStringLiteral("PHOTO"), addressee.photo(), version));
-        const QVector<Picture> lstExtraPhoto = addressee.extraPhotoList();
+        const QList<Picture> lstExtraPhoto = addressee.extraPhotoList();
         for (const Picture &photo : lstExtraPhoto) {
             card.addLine(createPicture(QStringLiteral("PHOTO"), photo, version));
         }
@@ -539,7 +535,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         card.addLine(VCardLine(QStringLiteral("REV"), createDateTime(addressee.revision(), version)));
 
         // ROLE
-        const QVector<Role> lstExtraRole = addressee.extraRoleList();
+        const QList<Role> lstExtraRole = addressee.extraRoleList();
         for (const Role &role : lstExtraRole) {
             VCardLine roleLine(QStringLiteral("ROLE"), role.role());
             if (version == VCard::v2_1 && needsEncoding(role.role())) {
@@ -557,7 +553,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
 
         // SOUND
         card.addLine(createSound(addressee.sound(), version));
-        const QVector<Sound> lstSound = addressee.extraSoundList();
+        const QList<Sound> lstSound = addressee.extraSoundList();
         for (const Sound &sound : lstSound) {
             card.addLine(createSound(sound, version));
         }
@@ -567,7 +563,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         processPhoneNumbers(phoneNumbers, version, &card);
 
         // TITLE
-        const QVector<Title> lstTitle = addressee.extraTitleList();
+        const QList<Title> lstTitle = addressee.extraTitleList();
         for (const Title &title : lstTitle) {
             VCardLine titleLine(QStringLiteral("TITLE"), title.title());
             if (version == VCard::v2_1 && needsEncoding(title.title())) {
@@ -598,7 +594,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         card.addLine(VCardLine(QStringLiteral("UID"), addressee.uid()));
 
         // URL
-        const QVector<ResourceLocatorUrl> lstExtraUrl = addressee.extraUrlList();
+        const QList<ResourceLocatorUrl> lstExtraUrl = addressee.extraUrlList();
         for (const ResourceLocatorUrl &url : lstExtraUrl) {
             VCardLine line(QStringLiteral("URL"), url.url());
             line.addParameters(url.params());
@@ -626,7 +622,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         }
         // From vcard4.
         if (version == VCard::v4_0) {
-            const QVector<CalendarUrl> lstCalendarUrl = addressee.calendarUrlList();
+            const QList<CalendarUrl> lstCalendarUrl = addressee.calendarUrlList();
             for (const CalendarUrl &url : lstCalendarUrl) {
                 if (url.isValid()) {
                     QString type;
@@ -654,7 +650,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         }
 
         // FieldGroup
-        const QVector<FieldGroup> lstGroup = addressee.fieldGroupList();
+        const QList<FieldGroup> lstGroup = addressee.fieldGroupList();
         for (const FieldGroup &group : lstGroup) {
             VCardLine line(group.fieldGroupName(), group.value());
             line.addParameters(group.params());
@@ -662,7 +658,7 @@ QByteArray VCardTool::createVCards(const Addressee::List &list, VCard::Version v
         }
 
         // IMPP (supported in vcard 3 too)
-        const QVector<Impp> lstImpp = addressee.imppList();
+        const QList<Impp> lstImpp = addressee.imppList();
         for (const Impp &impp : lstImpp) {
             VCardLine line(QStringLiteral("IMPP"), impp.address().url());
             const ParameterMap pMap = impp.params();
@@ -1056,14 +1052,9 @@ Addressee::List VCardTool::parseVCards(const QByteArray &vcard) const
                     const QString date = (*lineIt).value().toString();
 
                     if (!date.isEmpty()) {
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                         const QStringView dateView(date);
                         int hours = dateView.mid(1, 2).toInt();
                         int minutes = dateView.mid(4, 2).toInt();
-#else
-                        int hours = date.midRef(1, 2).toInt();
-                        int minutes = date.midRef(4, 2).toInt();
-#endif
                         int offset = (hours * 60) + minutes;
                         offset = offset * (date[0] == QLatin1Char('+') ? 1 : -1);
 
@@ -1205,11 +1196,7 @@ QDateTime VCardTool::parseDateTime(const QString &str, bool *timeValid)
     dateString.remove(QLatin1Char('-'));
     QDate date;
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     const QStringView dstr{dateString};
-#else
-    const QStringRef dstr(&dateString);
-#endif
     if (noYear) {
         date.setDate(-1, dstr.mid(0, 2).toInt(), dstr.mid(2, 2).toInt());
     } else {
@@ -1227,11 +1214,7 @@ QDateTime VCardTool::parseDateTime(const QString &str, bool *timeValid)
         const int plusPos = timeString.indexOf(QLatin1Char('+'));
         const int minusPos = timeString.indexOf(sep);
         const int tzPos = qMax(qMax(zPos, plusPos), minusPos);
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
         const QStringView hhmmssString = tzPos >= 0 ? QStringView(timeString).left(tzPos) : QStringView(timeString);
-#else
-        const QStringRef hhmmssString = tzPos >= 0 ? timeString.leftRef(tzPos) : QStringRef(&timeString);
-#endif
         int hour = 0;
         int minutes = 0;
         int seconds = 0;
@@ -1257,11 +1240,7 @@ QDateTime VCardTool::parseDateTime(const QString &str, bool *timeValid)
             } else {
                 spec = Qt::OffsetFromUTC;
 
-#if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
                 const auto offsetString = QStringView(timeString).mid(tzPos + 1);
-#else
-                const QStringRef offsetString = timeString.midRef(tzPos + 1);
-#endif
                 switch (offsetString.size()) {
                 case 2: // format: "hh"
                     offsetSecs = offsetString.left(2).toInt() * 3600;
